@@ -77,29 +77,29 @@ class User:
         """
         return await self.bot.send_message(self.chat_id, text, components=components)
 
-    async def send_document(self, document: bytes | str | "Document", *, caption: Optional[str] = None):
+    async def send_document(self, document: bytes | str | "Document", *, file_name: Optional[str] = None, caption: Optional[str] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_document`.
         """
-        return await self.bot.send_document(self.chat_id, document, caption=caption)
+        return await self.bot.send_document(self.chat_id, document, file_name=file_name, caption=caption)
 
-    async def send_photo(self, photo: bytes | str | "Photo", *, caption: Optional[str] = None):
+    async def send_photo(self, photo: bytes | str | "Photo", *, file_name: Optional[str] = None, caption: Optional[str] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_photo`.
         """
-        return await self.bot.send_photo(self.chat_id, photo, caption=caption)
+        return await self.bot.send_photo(self.chat_id, photo, file_name=file_name, caption=caption)
 
-    async def send_video(self, video: bytes | str | "Video", *, caption: Optional[str] = None):
+    async def send_video(self, video: bytes | str | "Video", *, file_name: Optional[str] = None, caption: Optional[str] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_video`.
         """
-        return await self.bot.send_video(self.chat_id, video, caption=caption)
+        return await self.bot.send_video(self.chat_id, video, file_name=file_name, caption=caption)
 
-    async def send_audio(self, audio: bytes | str | "Audio", *, caption: Optional[str] = None):
+    async def send_audio(self, audio: bytes | str | "Audio", *, file_name: Optional[str] = None, caption: Optional[str] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_audio`.
         """
-        return await self.bot.send_audio(self.chat_id, audio, caption=caption)
+        return await self.bot.send_audio(self.chat_id, audio, file_name=file_name, caption=caption)
 
     async def send_location(self, location: "Location"):
         """
